@@ -26,8 +26,6 @@
 #include <QDialog>
 #include <QShortcutEvent>
 #include <QMouseEvent>
-#include <QLayout>
-#include <QMenuBar>
 #include <QPushButton>
 #include <QTabBar>
 #include <QTextBrowser>
@@ -38,6 +36,9 @@
 #include <QClipboard>
 #include <QProcess>
 #include <QDialogButtonBox>
+#include <QAction>
+#include <QMenu>
+#include <QVBoxLayout>
 
 #include <kconfig.h>
 #include <kconfiggroup.h>
@@ -80,10 +81,44 @@ public Q_SLOTS:
 
 static void startupFunc()
 {
+    // Static because in some cases this is called multiple times
+    // but if an application had any of the bad cases we always want
+    // to skip the check
+    static bool doCheckAccelerators = true;
+
+    if (!doCheckAccelerators) {
+        return;
+    }
+
+    QCoreApplication *app = QCoreApplication::instance();
+    if (!app) {
+        // We're being loaded by something that doesn't have a QCoreApplication
+        // this would probably crash at some later point since we do use qApp->
+        // quite a lot, so skip the magic
+        doCheckAccelerators = false;
+        return;
+    }
+
+    if (!QCoreApplication::startingUp()) {
+        // If the app has already started, this means we're not being run as part of
+        // qt_call_pre_routines, which most probably means that we're being run as part
+        // of KXmlGui being loaded as part of some plugin of the app, so don't
+        // do any magic
+        doCheckAccelerators = false;
+        return;
+    }
+
+    if (!QCoreApplication::eventDispatcher()) {
+        // We are called with event dispatcher being null when KXmlGui is being loaded
+        // through plasma-integration instead of being linked to the app (i.e. QtCreator vs Okular)
+        // For apps that don't link directly to KXmlGui do not do the accelerator magic
+        doCheckAccelerators = false;
+        return;
+    }
+
+    KCheckAcceleratorsInitializer *initializer = new KCheckAcceleratorsInitializer(app);
     // Call initiateIfNeeded once we're in the event loop
     // This is to prevent using KSharedConfig before main() can set the app name
-    QCoreApplication *app = QCoreApplication::instance();
-    KCheckAcceleratorsInitializer *initializer = new KCheckAcceleratorsInitializer(app);
     QMetaObject::invokeMethod(initializer, "initiateIfNeeded", Qt::QueuedConnection);
 }
 
@@ -187,7 +222,7 @@ bool KCheckAccelerators::eventFilter(QObject *obj, QEvent *e)
                 clipboard->setText(text);
             } else {
                 QProcess *script = new QProcess(this);
-                script->start(copyWidgetTextCommand.arg(text, QFile::decodeName(KLocalizedString::applicationDomain())));
+                script->start(copyWidgetTextCommand.arg(text, QFile::decodeName(KLocalizedString::applicationDomain())), QStringList());
                 connect(script, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
                         script, &QObject::deleteLater);
             }
@@ -280,32 +315,32 @@ void KCheckAccelerators::checkAccelerators(bool automatic)
     QString s;
 
     if (! c.isEmpty())  {
-        s += i18n("<h2>Accelerators changed</h2>");
-        s += QStringLiteral("<table border><tr><th><b>");
-        s += i18n("Old Text");
-        s += QStringLiteral("</b></th><th><b>");
-        s += i18n("New Text");
-        s += QStringLiteral("</b></th></tr>");
-        s += c;
-        s += QStringLiteral("</table>");
+        s += i18n("<h2>Accelerators changed</h2>") +
+             QLatin1String("<table border><tr><th><b>") +
+             i18n("Old Text") +
+             QLatin1String("</b></th><th><b>") +
+             i18n("New Text") +
+             QLatin1String("</b></th></tr>") +
+             c +
+             QLatin1String("</table>");
     }
 
     if (! r.isEmpty())  {
-        s += i18n("<h2>Accelerators removed</h2>");
-        s += QStringLiteral("<table border><tr><th><b>");
-        s += i18n("Old Text");
-        s += QStringLiteral("</b></th></tr>");
-        s += r;
-        s += QStringLiteral("</table>");
+        s += i18n("<h2>Accelerators removed</h2>") +
+             QLatin1String("<table border><tr><th><b>") +
+             i18n("Old Text") +
+             QLatin1String("</b></th></tr>") +
+             r +
+             QLatin1String("</table>");
     }
 
     if (! a.isEmpty())  {
-        s += i18n("<h2>Accelerators added (just for your info)</h2>");
-        s += QStringLiteral("<table border><tr><th><b>");
-        s += i18n("New Text");
-        s += QStringLiteral("</b></th></tr>");
-        s += a;
-        s += QStringLiteral("</table>");
+        s += i18n("<h2>Accelerators added (just for your info)</h2>") +
+             QLatin1String("<table border><tr><th><b>") +
+             i18n("New Text") +
+             QLatin1String("</b></th></tr>") +
+             a +
+             QLatin1String("</table>");
     }
 
     createDialog(actWin, automatic);
